"use strict";

var path = require('path');
var fs = require('fs');
var express = require('express');
var ParseDashboard = require('parse-dashboard');
var host = process.env.HOST || '0.0.0.0';
var port = process.env.PARSE_DASHBOARD_PORT || process.env.PORT || 4040;
var mountPath = process.env.PARSE_DASHBOARD_MOUNT_PATH || process.env.MOUNT_PATH || '/';
var allowInsecureHTTP = process.env.PARSE_DASHBOARD_ALLOW_INSECURE_HTTP;
var cookieSessionSecret = process.env.PARSE_DASHBOARD_COOKIE_SESSION_SECRET;
var trustProxy = process.env.PARSE_DASHBOARD_TRUST_PROXY;
if (trustProxy && allowInsecureHTTP) {
  console.log('Set only trustProxy *or* allowInsecureHTTP, not both.  Only one is needed to handle being behind a proxy.');
  process.exit(1);
}
var configFile = null;
var configFromCLI = null;
var configServerURL = process.env.PARSE_DASHBOARD_SERVER_URL || process.env.PARSE_SERVER_URL;
var configGraphQLServerURL = process.env.PARSE_DASHBOARD_GRAPHQL_SERVER_URL;
var configPrimaryKey = process.env.PARSE_DASHBOARD_PRIMARY_KEY || process.env.PARSE_SERVER_PRIMARY_KEY;
var configAppId = process.env.PARSE_DASHBOARD_APP_ID || process.env.PARSE_SERVER_APPLICATION_ID;
var configAppName = process.env.PARSE_DASHBOARD_APP_NAME;
var configUsernames = process.env.PARSE_DASHBOARD_USERNAMES;
var configUserPasswords = process.env.PARSE_DASHBOARD_USER_PASSWORDS;
var configUserPasswordEncrypted = true;
if (process.env.PARSE_DASHBOARD_USER_PASSWORD_ENCRYPTED == 'false') {
  configUserPasswordEncrypted = false;
}
if (!process.env.PARSE_DASHBOARD_CONFIG) {
  if (configServerURL && configPrimaryKey && configAppId) {
    configFromCLI = {
      data: {
        apps: [{
          appId: configAppId,
          serverURL: configServerURL,
          masterKey: configPrimaryKey,
          appName: configAppName
        }]
      }
    };
    if (configGraphQLServerURL) {
      configFromCLI.data.apps[0].graphQLServerURL = configGraphQLServerURL;
    }
    if (configUsernames && configUserPasswords) {
      configUsernames = configUsernames.split(", ");
      configUserPasswords = configUserPasswords.split(", ");
      if (configUsernames.length == configUserPasswords.length) {
        var users = [];
        configUsernames.forEach(function (username, index) {
          users.push({
            user: username,
            pass: configUserPasswords[index]
          });
        });
        configFromCLI.data.users = users;
        configFromCLI.data.useEncryptedPasswords = configUserPasswordEncrypted;
      } else {
        console.log('Dashboard usernames(' + configUsernames.length + ') ' + 'and passwords(' + configUserPasswords.length + ') must be the same size.');
        process.exit(1);
      }
    }
  } else if (!configServerURL && !configPrimaryKey && !configAppName) {
    configFile = path.join(__dirname, 'lib', 'parse-dashboard-config.json');
  }
} else {
  configFromCLI = {
    data: JSON.parse(process.env.PARSE_DASHBOARD_CONFIG)
  };
}
var config = null;
var configFilePath = null;
if (configFile) {
  try {
    config = {
      data: JSON.parse(fs.readFileSync(configFile, 'utf8'))
    };
    configFilePath = path.dirname(configFile);
  } catch (error) {
    if (error instanceof SyntaxError) {
      console.log('Your config file contains invalid JSON. Exiting.');
      process.exit(1);
    } else if (error.code === 'ENOENT') {
      console.log('You must provide either a config file or required CLI options (app ID, Primary Key, and server URL); not both.');
      process.exit(3);
    } else {
      console.log('There was a problem with your config. Exiting.');
      process.exit(1);
    }
  }
} else if (configFromCLI) {
  config = configFromCLI;
} else {
  //Failed to load default config file.
  console.log('You must provide either a config file or an app ID, Primary Key, and server URL. See parse-dashboard --help for details.');
  process.exit(4);
}
config.data.apps.forEach(function (app) {
  if (!app.appName) {
    app.appName = app.appId;
  }
});
if (config.data.iconsFolder && configFilePath) {
  config.data.iconsFolder = path.join(configFilePath, config.data.iconsFolder);
}
var app = express();
if (allowInsecureHTTP || trustProxy) app.enable('trust proxy');
config.data.trustProxy = trustProxy;
var dashboardOptions = {
  allowInsecureHTTP: allowInsecureHTTP,
  cookieSessionSecret: cookieSessionSecret
};
var dashboard = new ParseDashboard(config.data, dashboardOptions);
app.use(mountPath, dashboard);
var server = app.listen(port, host, function () {
  console.log("The dashboard is now available at http://".concat(server.address().address, ":").concat(server.address().port).concat(mountPath));
});
//# sourceMappingURL=index.js.map